> [!NOTE]
> If there are missing Ref Types missing from Ledger please let me know\\

This Show which Category has which Ref Type

# Categories

## Asset Safety Cost

- asset_safety_recovery_tax

## Citadel

- copying
- industry_job_tax
- manufacturing
- reaction
- reprocessing_tax
- researching_material_productivity
- researching_time_productivity

## Contract & Contract Cost

- contract_brokers_fee
- contract_collateral
- contract_collateral_refund
- contract_deposit_refund
- contract_price
- contract_price_payment_corp
- contract_reward
- contract_reward_deposited
- contract_reward_refund
- contract_sales_tax

## Daily Goal

- daily_goal_payouts

## Donation

- player_donation

## Donation Sent

- corporation_account_withdrawal
- player_donation

## ESS

- ess_escrow_transfer

## Insurance & Insurance Cost

- insurance

## Market & Market Cost

- brokers_fee
- market_escrow
- market_provider_tax
- market_transaction
- transaction_tax

## Mission Reward

- agent_mission_reward
- agent_mission_time_bonus_reward

## Planetary Cost

- planetary_construction
- planetary_export_tax
- planetary_import_tax

## Production Cost

- copying
- industry_job_tax
- manufacturing
- reaction
- reprocessing_tax
- researching_material_productivity
- researching_time_productivity

## Rental Cost

- office_rental_fee

## Ratting

- bounty_prizes

## Skillbook Cost

- skill_purchase

## Traveling Cost

- jump_clone_activation_fee
- jump_clone_installation_fee
- structure_gate_jump
